@@ -12,7 +12,6 @@ import fk.utils
 import fk.utils.Watchdog
 from pprint import pformat
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -213,7 +212,13 @@ class BatchProcessor:
         try:
             watchdog = fk.utils.Watchdog.Watchdog(timeout)
             # logger.info("££££ Entry")
-            result, failure = entrypoint(item, self.config)
+            unpackable = entrypoint(item, self.config)
+            try:
+                result, failure = unpackable
+            except TypeError as te:
+                failure = f"Filter did not return exactly one value and one error"
+                logger.warning(failure)
+                return None, failure
             # logger.info("££££ Exit")
         except fk.utils.Watchdog.Watchdog:
             logger.warning("Watchdag triggered exception")
@@ -223,15 +228,18 @@ class BatchProcessor:
             logger.warning("")
             logger.warning(f"###############################################")
             logger.warning(f"#    Batch item: {item}")
-            logger.warning(f"# Failed with: {e}")
-            failure = f"{e}"
+            logger.warning(f"# Failed with: {e} ({type(e).__name__}, {e.args})")
+            failure = f"{e}  ({type(e).__name__}, {e.args})"
             logger.warning(f"#          At:")
             traceback.print_exc()
             logger.warning(f"#######################################")
             logger.warning("")
             logger.warning("")
-        watchdog.stop()
+        if None is not watchdog:
+            watchdog.stop()
         # logger.info("SAFE EXECUTION FINISHED!")
+
+        watchdog = None
         return result, failure
 
     def execute_one_batch_item(self):
@@ -268,7 +276,6 @@ class BatchProcessor:
         # logger.info(f"No pending items found")
         return False
 
-
     def execute_one_throttled_batch_item(self):
         """
         Take ownership of one batch item and make sure it is properly executed and updated with status underway
@@ -283,10 +290,10 @@ class BatchProcessor:
             t = item.get("type", None)
             updated_at = item.get("updated_at", None)
             if id and t and updated_at:
-                if item.get('wait_millis', 0)>0:
+                if item.get("wait_millis", 0) > 0:
                     logger.warning("Item not booked")
                     logger.warning(pformat(item))
-                    failure="Not booked"
+                    failure = "Not booked"
                 else:
                     entrypoint, failure = self.get_callable_for_type(t)
                     if entrypoint and failure:
@@ -341,15 +348,21 @@ class BatchProcessor:
     def delete_all_jobs(self, time_sec=30):
         self.db.delete_all()
 
+    def bump_job_by_id(self, id, status):
+        self.db.bump_batch_item_status(id, status)
+
+    def retry_job_by_id(self, id):
+        self.db.bump_batch_item_status(id, self.db.PENDING)
+
     def get_job_counts(self):
         raw = self.db.get_job_counts()
-        out={}
+        out = {}
         for row in raw:
-            t=row.get('type')
-            s=row.get('status')
-            c=row.get('count')
-            out[t]=out.get(t,{})
-            out[t][s]=c
+            t = row.get("type")
+            s = row.get("status")
+            c = row.get("count")
+            out[t] = out.get(t, {})
+            out[t][s] = c
         return out
 
     def get_status(self):
